pub struct TestIcon;Trait Implementations
Sourceimpl SimpleIcon for TestIcon
impl SimpleIcon for TestIcon
fn icon(&self) -> &'static str
Sourcefn apply_style(&self, string: &str) -> String
fn apply_style(&self, string: &str) -> String
string will go into the be put into the ICON svg like this style=“{}”
Sourcefn apply_class(&self, string: &str) -> String
fn apply_class(&self, string: &str) -> String
string will go into the be put into the ICON svg like this class=“{}”
fn apply_fill(&self, string: &str) -> String
fn apply_id(&self, string: &str) -> String